==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/floppy/dialogs_it.lua <==

dialogId("disk-v-tady", "font_big", "It looks as if we finally got there.")
dialogStr("Finalmente siamo arrivati, sembra.")

dialogId("disk-m-tady", "font_small", "Do you think this is it?")
dialogStr("Pensi che sia questo?")

dialogId("disk-m-vejit", "font_small", "How could it all fit on one three and a half inch floppy?")
dialogStr("Come può stare tutto dentro ad un dischetto da 3.5\"?")

dialogId("disk-v-metrova", "font_big", "Look how much bigger than me it is. It is a three and a half meter floppy.")
dialogStr("Guarda quanto è più grande di me. Questo è un dischetto da 3 metri e mezzo.")

dialogId("disk-m-velka", "font_small", "That`s better. Big plan, big disk. That makes sense.")
dialogStr("Giusto. Grande piano, grande dischetto. Ha senso.")

dialogId("disk-m-zvednem", "font_small", "Do you think we can lift it up?")
dialogStr("Pensi che riusciremo a sollevarlo?")

dialogId("disk-v-tezko", "font_big", "It will be difficult.")
dialogStr("Difficile.")

dialogId("disk-v-nejde", "font_big", "I don't think it can be done. Why would they be hiding it here, if we could lift it?")
dialogStr("Non penso sia fattibile. Perché lo avrebbero nascosto qui, se riuscissimo a sollevarlo?")

dialogId("disk-v-ulamu", "font_big", "Shut up, or I will break off your pins!")
dialogStr("Smettila, o ti spezzo i piedini!")

dialogId("disk-v-kriz", "font_big", "Can you see that steel cross? This is the grave of our hopes.")
dialogStr("Vedi quella croce di acciaio? Quella è la tomba delle nostre speranze.")

dialogId("disk-m-depres", "font_small", "Don`t be always so gloomy. I can`t bear it.")
dialogStr("Non essere sempre così deprimente. Non lo sopporto.")

dialogId("disk-m-nahrat", "font_small", "Wouldn`t it be enough to download that plan from the floppy to our notebook?")
dialogStr("Non basterebbe scaricare il piano dal dischetto al nostro portatile?")

dialogId("disk-v-mas", "font_big", "Why not. Take it out.")
dialogStr("Perché no? Tiralo fuori.")

dialogId("disk-m-sakra", "font_small", "Oh, darn! I left it at home.")
dialogStr("Oh diamine! L'ho lasciato a casa.")

dialogId("disk-v-vratime", "font_big", "Shall we return for it?")
dialogStr("Dovremmo tornare a prenderlo?")

dialogId("disk-v-naano", "font_big", "Never. It may seem funny to you, but my fins are sore.")
dialogStr("Mai. Ti sembrerà molto divertente, ma mi fanno male le pinne.")

dialogId("disk-v-nane", "font_big", "Suit yourself. I am curious how are you going to do it now.")
dialogStr("Come vuoi. Ma sono curioso di vedere come ci riuscirai, adesso.")

dialogId("disk-m-zmatlo", "font_small", "What if there is no plan on this floppy? What if it is here only to confound us?")
dialogStr("E se nel dischetto non ci fosse nessun piano? Se fosse stato messo qui solo per confonderci?")

dialogId("disk-v-neverim", "font_big", "I don`t believe that. Is there some other object that would be more difficult to get out?")
dialogStr("Non credo. C'è forse qualcos'altro di più difficle per noi da portar fuori?")

dialogId("disk-m-tvorecci", "font_small", "What kind of little creatures are those?")
dialogStr("Che razza di creaturine sono quelle?")

dialogId("disk-v-viry", "font_big", "These must be computer viruses.")
dialogStr("Devono essere virus informatici.")

dialogId("disk-m-potvory", "font_small", "Yuck. Some monsters.")
dialogStr("Bleah. Che mostriciattoli.")

dialogId("disk-v-pozor", "font_big", "Above all, we must be careful not to take them with the disk. The player wouldn`t be happy if we pour them on their desktop.")
dialogStr("Tra l'altro, dobbiamo stare attenti a non portarceli via col disco. Il giocatore non sarebbe tanto felice di ritrovarseli sul suo desktop.")

dialogId("disk-m-ukol", "font_small", "Our goal is to push out that disk.")
dialogStr("Il nostro obiettivo e tirar fuori il dischetto.")

dialogId("disk-x-nepohnes", "font_darkgrey", "You won`t move me easily!")
dialogStr("Non mi sposterete facilmente!")

dialogId("disk-x-mazany", "font_darkgrey", "That was smart!")
dialogStr("Sagace!")

dialogId("disk-x-jejda0", "font_darkgrey", "Ooops!")
dialogStr("Oops!")

dialogId("disk-x-jejda1", "font_darkgrey", "Darn!")
dialogStr("Maledizione!")

dialogId("disk-x-au0", "font_darkgrey", "Oh.")
dialogStr("Ahio.")

dialogId("disk-x-au1", "font_darkgrey", "Ouch.")
dialogStr("Ohi.")

dialogId("disk-x-au2", "font_darkgrey", "Yup.")
dialogStr("Ah.")

dialogId("disk-x-uzne", "font_darkgrey", "Leave me alone!")
dialogStr("Lasciatemi solo!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/floppy/dialogs_it.lua <==

dialogId("disk-v-tady", "font_big", "It looks as if we finally got there.")
dialogStr("Finalmente siamo arrivati, sembra.")

dialogId("disk-m-tady", "font_small", "Do you think this is it?")
dialogStr("Pensi che sia questo?")

dialogId("disk-m-vejit", "font_small", "How could it all fit on one three and a half inch floppy?")
dialogStr("Come può stare tutto dentro ad un dischetto da 3.5\"?")

dialogId("disk-v-metrova", "font_big", "Look how much bigger than me it is. It is a three and a half meter floppy.")
dialogStr("Guarda quanto è più grande di me. Questo è un dischetto da 3 metri e mezzo.")

dialogId("disk-m-velka", "font_small", "That’s better. Big plan, big disk. That makes sense.")
dialogStr("Giusto. Grande piano, grande dischetto. Ha senso.")

dialogId("disk-m-zvednem", "font_small", "Do you think we can lift it up?")
dialogStr("Pensi che riusciremo a sollevarlo?")

dialogId("disk-v-tezko", "font_big", "It will be difficult.")
dialogStr("Difficile.")

dialogId("disk-v-nejde", "font_big", "I don't think it can be done. Why would they be hiding it here, if we could lift it?")
dialogStr("Non penso sia fattibile. Perché lo avrebbero nascosto qui, se riuscissimo a sollevarlo?")

dialogId("disk-v-ulamu", "font_big", "Shut up, or I will break off your pins!")
dialogStr("Smettila, o ti spezzo i piedini!")

dialogId("disk-v-kriz", "font_big", "Can you see that steel cross? This is the grave of our hopes.")
dialogStr("Vedi quella croce di acciaio? Quella è la tomba delle nostre speranze.")

dialogId("disk-m-depres", "font_small", "Don’t be always so gloomy. I can’t bear it.")
dialogStr("Non essere sempre così deprimente. Non lo sopporto.")

dialogId("disk-m-nahrat", "font_small", "Wouldn’t it be enough to download that plan from the floppy to our notebook?")
dialogStr("Non basterebbe scaricare il piano dal dischetto al nostro portatile?")

dialogId("disk-v-mas", "font_big", "Why not. Take it out.")
dialogStr("Perché no? Tiralo fuori.")

dialogId("disk-m-sakra", "font_small", "Oh, darn! I left it at home.")
dialogStr("Oh diamine! L'ho lasciato a casa.")

dialogId("disk-v-vratime", "font_big", "Shall we return for it?")
dialogStr("Dovremmo tornare a prenderlo?")

dialogId("disk-v-naano", "font_big", "Never. It may seem funny to you, but my fins are sore.")
dialogStr("Mai. Ti sembrerà molto divertente, ma mi fanno male le pinne.")

dialogId("disk-v-nane", "font_big", "Suit yourself. I am curious how are you going to do it now.")
dialogStr("Come vuoi. Ma sono curioso di vedere come ci riuscirai, adesso.")

dialogId("disk-m-zmatlo", "font_small", "What if there is no plan on this floppy? What if it is here only to confound us?")
dialogStr("E se nel dischetto non ci fosse nessun piano? Se fosse stato messo qui solo per confonderci?")

dialogId("disk-v-neverim", "font_big", "I don’t believe that. Is there some other object that would be more difficult to get out?")
dialogStr("Non credo. C'è forse qualcos'altro di più difficle per noi da portar fuori?")

dialogId("disk-m-tvorecci", "font_small", "What kind of little creatures are those?")
dialogStr("Che razza di creaturine sono quelle?")

dialogId("disk-v-viry", "font_big", "These must be computer viruses.")
dialogStr("Devono essere virus informatici.")

dialogId("disk-m-potvory", "font_small", "Yuck. Some monsters.")
dialogStr("Bleah. Che mostriciattoli.")

dialogId("disk-v-pozor", "font_big", "Above all, we must be careful not to take them with the disk. The player wouldn’t be happy if we pour them on their desktop.")
dialogStr("Tra l'altro, dobbiamo stare attenti a non portarceli via col disco. Il giocatore non sarebbe tanto felice di ritrovarseli sul suo desktop.")

dialogId("disk-m-ukol", "font_small", "Our goal is to push out that disk.")
dialogStr("Il nostro obiettivo e tirar fuori il dischetto.")

dialogId("disk-x-nepohnes", "font_darkgrey", "You won’t move me easily!")
dialogStr("Non mi sposterete facilmente!")

dialogId("disk-x-mazany", "font_darkgrey", "That was smart!")
dialogStr("Sagace!")

dialogId("disk-x-jejda0", "font_darkgrey", "Ooops!")
dialogStr("Oops!")

dialogId("disk-x-jejda1", "font_darkgrey", "Darn!")
dialogStr("Maledizione!")

dialogId("disk-x-au0", "font_darkgrey", "Oh.")
dialogStr("Ahio.")

dialogId("disk-x-au1", "font_darkgrey", "Ouch.")
dialogStr("Ohi.")

dialogId("disk-x-au2", "font_darkgrey", "Yup.")
dialogStr("Ah.")

dialogId("disk-x-uzne", "font_darkgrey", "Leave me alone!")
dialogStr("Lasciatemi solo!")
